==> nautilus-2.14.1.tar.gz: nautilus-2.14.1/libnautilus-private/nautilus-program-choosing.h <==
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */

/* nautilus-program-choosing.h - functions for selecting and activating
 				 programs for opening/viewing particular files.

   Copyright (C) 2000 Eazel, Inc.

   The Gnome Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   The Gnome Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with the Gnome Library; see the file COPYING.LIB.  If not,
   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.

   Author: John Sullivan <sullivan@eazel.com>
*/

#ifndef NAUTILUS_PROGRAM_CHOOSING_H
#define NAUTILUS_PROGRAM_CHOOSING_H

#include <gtk/gtkwindow.h>
#include <libgnomevfs/gnome-vfs-mime-handlers.h>
#include <libnautilus-private/nautilus-file.h>

#define NAUTILUS_COMMAND_SPECIFIER "command:"
#define NAUTILUS_DESKTOP_COMMAND_SPECIFIER "desktop-file:"

typedef void (*NautilusApplicationChoiceCallback) (GnomeVFSMimeApplication	 *application,
						   gpointer			  callback_data);

void nautilus_launch_application                 (GnomeVFSMimeApplication           *application,
						  GList                             *files,
						  GtkWindow                         *parent_window);
void nautilus_launch_application_from_command    (GdkScreen                         *screen,
						  const char                        *name,
						  const char                        *command_string,
						  const char                        *parameter,
						  gboolean                           use_terminal);
void nautilus_launch_desktop_file		 (GdkScreen                         *screen,
						  const char                        *desktop_file_uri,
						  const GList                       *parameter_uris,
						  GtkWindow                         *parent_window);
void nautilus_launch_show_file                   (NautilusFile                      *file,
                                                  GtkWindow                         *parent_window);
						  
#endif /* NAUTILUS_PROGRAM_CHOOSING_H */

==> nautilus-2.21.90.tar.gz: nautilus-2.21.90/libnautilus-private/nautilus-program-choosing.h <==
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */

/* nautilus-program-choosing.h - functions for selecting and activating
 				 programs for opening/viewing particular files.

   Copyright (C) 2000 Eazel, Inc.

   The Gnome Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   The Gnome Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with the Gnome Library; see the file COPYING.LIB.  If not,
   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.

   Author: John Sullivan <sullivan@eazel.com>
*/

#ifndef NAUTILUS_PROGRAM_CHOOSING_H
#define NAUTILUS_PROGRAM_CHOOSING_H

#include <gtk/gtkwindow.h>
#include <gio/gio.h>
#include <libnautilus-private/nautilus-file.h>

#define NAUTILUS_COMMAND_SPECIFIER "command:"
#define NAUTILUS_DESKTOP_COMMAND_SPECIFIER "desktop-file:"

typedef void (*NautilusApplicationChoiceCallback) (GAppInfo                      *application,
						   gpointer			  callback_data);

void nautilus_launch_application                 (GAppInfo                          *application,
						  GList                             *files,
						  GtkWindow                         *parent_window);
void nautilus_launch_application_from_command    (GdkScreen                         *screen,
						  const char                        *name,
						  const char                        *command_string,
						  const char                        *parameter,
						  gboolean                           use_terminal);
void nautilus_launch_desktop_file		 (GdkScreen                         *screen,
						  const char                        *desktop_file_uri,
						  const GList                       *parameter_uris,
						  GtkWindow                         *parent_window);
						  
#endif /* NAUTILUS_PROGRAM_CHOOSING_H */
